@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Author: Radek Doulik <rodo@helixcode.com>
 */
@@ -53,7 +53,9 @@ gtk_html_control_data_new (GtkHTML *html, GtkWidget *vbox)
 	ncd->replace_text_replace    = NULL;
 	ncd->has_spell_control_set   = FALSE;
 	ncd->language                = NULL;
-	ncd->icon_theme              = gnome_icon_theme_new ();
+	ncd->paragraph_style_store   = NULL;
+
+	ncd->file_path = g_strdup (g_get_home_dir ());
 
 	spell_init (html, ncd);
 
@@ -80,20 +82,20 @@ gtk_html_control_data_destroy (GtkHTMLControlData *cd)
 	/* printf ("release dict\n"); */
 	bonobo_object_release_unref (cd->dict, NULL);
 
-	if (cd->plain_painter) 
+	if (cd->plain_painter)
 		g_object_unref (cd->plain_painter);
 
-	if (cd->gdk_painter) 
+	if (cd->gdk_painter)
 		g_object_unref (cd->gdk_painter);
 
 	if (cd->languages)
 		CORBA_free (cd->languages);
 	g_free (cd->language);
 
-	if (cd->icon_theme) {
-		g_object_unref (cd->icon_theme);
-		cd->icon_theme = NULL;
-	}
+	if (cd->paragraph_style_store)
+		g_object_unref (cd->paragraph_style_store);
+
+	g_free (cd->file_path);
 
 	g_free (cd);
 }
